#' Index of Countries.
#'
#' Data frame containing a normalized index of countries.\cr
#' Data are used by \code{\link{biblioAnalysis}} function 
#' to extract Country Field of Cited References and Authors. 
#'
#' @format A data frame with 198 rows and 1 variable:
#'  \describe{
#'     \item{countries}{country names}
#'     }
#' 
#' @name countries
NULL